@@ -57,15 +57,16 @@ def test_generate_data(model_data_with_cleanup):
     generate_data(test_data_path, test_result_path)
     assert test_result_path.exists()
     assert test_result_path.is_dir()
-    assert (test_result_path / "api_config.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").is_file()
     assert (test_result_path / "models").exists()
     assert (test_result_path / "models").is_dir()
-    assert (test_result_path / "services").exists()
-    assert (test_result_path / "services").is_dir()
     assert (test_result_path / "models" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").is_file()
     assert (test_result_path / "models" / "__init__.py").is_file()
+    assert (test_result_path / "clients").exists()
+    assert (test_result_path / "clients").is_dir()
+    assert (test_result_path / "clients" / "__init__.py").exists()
+    assert (test_result_path / "clients" / "__init__.py").is_file()
     assert (test_result_path / "__init__.py").exists()
     assert (test_result_path / "__init__.py").is_file()
 
@@ -76,15 +77,16 @@ def test_write_data(model_data_with_cleanup):
 
     assert test_result_path.exists()
     assert test_result_path.is_dir()
-    assert (test_result_path / "api_config.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").is_file()
     assert (test_result_path / "models").exists()
     assert (test_result_path / "models").is_dir()
-    assert (test_result_path / "services").exists()
-    assert (test_result_path / "services").is_dir()
     assert (test_result_path / "models" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").is_file()
     assert (test_result_path / "models" / "__init__.py").is_file()
+    assert (test_result_path / "clients").exists()
+    assert (test_result_path / "clients").is_dir()
+    assert (test_result_path / "clients" / "__init__.py").exists()
+    assert (test_result_path / "clients" / "__init__.py").is_file()
     assert (test_result_path / "__init__.py").exists()
     assert (test_result_path / "__init__.py").is_file()
 
@@ -100,15 +102,16 @@ def test_write_data(model_data_with_cleanup):
 
     assert test_result_path.exists()
     assert test_result_path.is_dir()
-    assert (test_result_path / "api_config.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").is_file()
     assert (test_result_path / "models").exists()
     assert (test_result_path / "models").is_dir()
-    assert (test_result_path / "services").exists()
-    assert (test_result_path / "services").is_dir()
     assert (test_result_path / "models" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").is_file()
     assert (test_result_path / "models" / "__init__.py").is_file()
+    assert (test_result_path / "clients").exists()
+    assert (test_result_path / "clients").is_dir()
+    assert (test_result_path / "clients" / "__init__.py").exists()
+    assert (test_result_path / "clients" / "__init__.py").is_file()
     assert (test_result_path / "__init__.py").exists()
     assert (test_result_path / "__init__.py").is_file()
 
@@ -121,15 +124,16 @@ def test_write_formatted_data(model_data_with_cleanup):
 
     assert test_result_path.exists()
     assert test_result_path.is_dir()
-    assert (test_result_path / "api_config.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").is_file()
     assert (test_result_path / "models").exists()
     assert (test_result_path / "models").is_dir()
-    assert (test_result_path / "services").exists()
-    assert (test_result_path / "services").is_dir()
     assert (test_result_path / "models" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").is_file()
     assert (test_result_path / "models" / "__init__.py").is_file()
+    assert (test_result_path / "clients").exists()
+    assert (test_result_path / "clients").is_dir()
+    assert (test_result_path / "clients" / "__init__.py").exists()
+    assert (test_result_path / "clients" / "__init__.py").is_file()
     assert (test_result_path / "__init__.py").exists()
     assert (test_result_path / "__init__.py").is_file()
 
@@ -147,15 +151,16 @@ def test_write_formatted_data(model_data_with_cleanup):
 
     assert test_result_path.exists()
     assert test_result_path.is_dir()
-    assert (test_result_path / "api_config.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").exists()
+    assert (test_result_path / "exceptions" / "__init__.py").is_file()
     assert (test_result_path / "models").exists()
     assert (test_result_path / "models").is_dir()
-    assert (test_result_path / "services").exists()
-    assert (test_result_path / "services").is_dir()
     assert (test_result_path / "models" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").exists()
-    assert (test_result_path / "services" / "__init__.py").is_file()
     assert (test_result_path / "models" / "__init__.py").is_file()
+    assert (test_result_path / "clients").exists()
+    assert (test_result_path / "clients").is_dir()
+    assert (test_result_path / "clients" / "__init__.py").exists()
+    assert (test_result_path / "clients" / "__init__.py").is_file()
     assert (test_result_path / "__init__.py").exists()
     assert (test_result_path / "__init__.py").is_file()
 
